==> MeUtils-2023.12.26.18.51.35-py3-none-any.whl: meutils/clis/browser.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : browser
# @Time         : 2023/11/29 15:52
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo: 持续刷新不掉线
import json

import pandas as pd

from meutils.pipe import *
from meutils.decorators.retry import retrying

from playwright.async_api import Playwright, async_playwright

cli = typer.Typer(name="模拟浏览器")


@retrying
async def refresh_cookies(
        url: str = "https://kimi.moonshot.cn/",
        headless: bool = False,
        storage_state: str = 'kimi_*.json',
        timeout: int = 3000
):
    """刷新cookies"""
    storages = []

    for storage_state in Path(Path(storage_state).parent).glob(Path(storage_state).name):
        async with async_playwright() as playwright:
            browser = await playwright.chromium.launch(headless=headless)
            context = await browser.new_context(storage_state=storage_state if Path(storage_state).exists() else None)

            page = await context.new_page()

            ####################################################################################

            await page.goto(url)
            await page.wait_for_load_state(state='load')
            await page.wait_for_load_state(state='networkidle')
            await page.wait_for_load_state(state='domcontentloaded')
            await page.wait_for_timeout(timeout=timeout)

            ####################################################################################
            # ---------------------
            # 保存状态文件
            storage = await context.storage_state(path=storage_state)  # 覆盖更新
            storages.append(storage)
            await context.close()
            await browser.close()
    return storages


@retrying
async def deepseek_sign_in(  # todo
        user_file: str = '',
        headless: bool = False,
        timeout: int = 1000,
        **kwargs
):
    url = "https://chat.deepseek.com/sign_in"
    storages = []
    df = pd.read_csv(user_file, sep=' ', names=['user', 'password'])
    for _, user, password in df.itertuples():
        async with async_playwright() as playwright:
            browser = await playwright.chromium.launch(headless=headless)
            context = await browser.new_context()

            page = await context.new_page()

            ####################################################################################

            await page.goto(url)
            await page.wait_for_load_state(state='load')
            await page.wait_for_load_state(state='networkidle')
            await page.wait_for_load_state(state='domcontentloaded')
            await page.wait_for_timeout(timeout=timeout)

            await page.get_by_placeholder("请输入手机号/邮箱地址").fill(user)  # todo: 账号密码
            await page.get_by_placeholder("请输入手机号/邮箱地址").press("Tab")
            await page.get_by_placeholder("请输入密码").fill(password)
            await page.get_by_role("img").nth(3).click()
            await page.get_by_role("button", name="登录").click()

            await page.wait_for_load_state(state='load')
            await page.wait_for_load_state(state='networkidle')
            await page.wait_for_load_state(state='domcontentloaded')
            await page.wait_for_timeout(timeout=timeout)

            # # 聊天
            await page.get_by_placeholder("请输入问题。Enter 发送，Ctrl + Enter 换行").fill("你是谁")
            await page.get_by_role("button", name="发送").click()

            ####################################################################################

            # ---------------------
            # 保存状态文件
            storage_state = f'{Path(user_file).parent}/deepseek_{user}.json'
            storage = await context.storage_state(path=storage_state)  # 覆盖更新
            storages.append(storage)
            await context.close()
            await browser.close()

    return storages


@cli.command()
def prun(
        url: str = "https://kimi.moonshot.cn/",
        headless: bool = True,
        storage_state: str = 'kimi_state.json',
        kwargs: str = typer.Option(None, help="The kwargs to parse.")
):
    """
    # 刷新cookies
    mecli-browser --no-headless --url  https://kimi.moonshot.cn/
    # 模拟登录
    mecli-browser --no-headless --kwargs '{"task": "deepseek", "user_file":"deepseek.txt"}'
    python browser.py --kwargs '{"task": "deepseek", "user_file":"deepseek.txt"}' --no-headless

    """
    kwargs = kwargs and json.loads(kwargs) or {}
    logger.debug(kwargs)
    if kwargs.get('task') == 'deepseek':  # TASK
        task = deepseek_sign_in(headless=headless, **kwargs)

    else:
        task = refresh_cookies(url, headless, storage_state)

    logger.info(asyncio.run(task))


if __name__ == '__main__':
    cli()
    # storage_state = '/Users/betterme/PycharmProjects/AI/MeUtils/meutils/clis/kimi_*.json'
    # print(Path(Path(storage_state).parent).glob(Path(storage_state).name) | xlist)

==> MeUtils-2023.12.27.9.54.58-py3-none-any.whl: meutils/clis/browser.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : browser
# @Time         : 2023/11/29 15:52
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo: 持续刷新不掉线
import json

import pandas as pd

from meutils.pipe import *
from meutils.decorators.retry import retrying

from playwright.async_api import Playwright, async_playwright

cli = typer.Typer(name="模拟浏览器")


@retrying
async def refresh_cookies(
        url: str = "https://kimi.moonshot.cn/",
        headless: bool = False,
        storage_state: str = 'kimi_*.json',
        timeout: int = 3000
):
    """刷新cookies"""
    storages = []

    for storage_state in Path(Path(storage_state).parent).glob(Path(storage_state).name):
        async with async_playwright() as playwright:
            browser = await playwright.chromium.launch(headless=headless)
            context = await browser.new_context(storage_state=storage_state if Path(storage_state).exists() else None)

            page = await context.new_page()

            ####################################################################################

            await page.goto(url)
            await page.wait_for_load_state(state='load')
            await page.wait_for_load_state(state='networkidle')
            await page.wait_for_load_state(state='domcontentloaded')
            await page.wait_for_timeout(timeout=timeout)

            ####################################################################################
            # ---------------------
            # 保存状态文件
            storage = await context.storage_state(path=storage_state)  # 覆盖更新
            print(Path(storage_state).absolute())
            storages.append(storage)
            await context.close()
            await browser.close()
    return storages


@retrying
async def deepseek_sign_in(  # todo
        user_file: str = '',
        headless: bool = False,
        timeout: int = 1000,
        **kwargs
):
    url = "https://chat.deepseek.com/sign_in"
    storages = []
    df = pd.read_csv(user_file, sep=' ', names=['user', 'password'])
    for _, user, password in df.itertuples():
        async with async_playwright() as playwright:
            browser = await playwright.chromium.launch(headless=headless)
            context = await browser.new_context()

            page = await context.new_page()

            ####################################################################################

            await page.goto(url)
            await page.wait_for_load_state(state='load')
            await page.wait_for_load_state(state='networkidle')
            await page.wait_for_load_state(state='domcontentloaded')
            await page.wait_for_timeout(timeout=timeout)

            await page.get_by_placeholder("请输入手机号/邮箱地址").click()
            await page.get_by_placeholder("请输入手机号/邮箱地址").fill(user)
            await page.get_by_placeholder("请输入手机号/邮箱地址").press("Tab")
            await page.get_by_placeholder("请输入密码").fill(password)
            await page.get_by_role("img").nth(3).click()
            await page.get_by_role("button", name="登录").click()

            await page.wait_for_load_state(state='load')
            await page.wait_for_load_state(state='networkidle')
            await page.wait_for_load_state(state='domcontentloaded')
            await page.wait_for_timeout(timeout=timeout)

            # # 聊天
            await page.get_by_placeholder("请输入问题。Enter 发送，Ctrl + Enter 换行").fill("你是谁")
            await page.get_by_role("button", name="发送").click()

            ####################################################################################

            # ---------------------
            # 保存状态文件
            storage_state = f'{Path(user_file).parent}/deepseek_{user}.json'
            storage = await context.storage_state(path=storage_state)  # 覆盖更新
            storages.append(storage)
            await context.close()
            await browser.close()

    return storages


@cli.command()
def prun(
        url: str = "https://kimi.moonshot.cn/",
        headless: bool = True,
        storage_state: str = 'kimi_state.json',
        kwargs: str = typer.Option(None, help="The kwargs to parse.")
):
    """
    # 刷新cookies
    mecli-browser --no-headless --url  https://kimi.moonshot.cn/
    # 模拟登录
    mecli-browser --no-headless --kwargs '{"task": "deepseek", "user_file":"deepseek.txt"}'
    python browser.py --kwargs '{"task": "deepseek", "user_file":"deepseek.txt"}' --no-headless

    """
    kwargs = kwargs and json.loads(kwargs) or {}
    logger.debug(kwargs)
    if kwargs.get('task') == 'deepseek':  # TASK
        task = deepseek_sign_in(headless=headless, **kwargs)

    else:
        task = refresh_cookies(url, headless, storage_state)

    logger.info(asyncio.run(task))


if __name__ == '__main__':
    cli()
    # storage_state = '/Users/betterme/PycharmProjects/AI/MeUtils/meutils/clis/kimi_*.json'
    # print(Path(Path(storage_state).parent).glob(Path(storage_state).name) | xlist)
